# 😻 Bot UI Kitty

[![Development Status](https://img.shields.io/pypi/status/bot-ui-kitty)](https://pypi.org/project/bot-ui-kitty/)
[![Latest Version on PyPI](https://img.shields.io/pypi/v/bot-ui-kitty)](https://pypi.org/project/bot-ui-kitty/)
[![Supported Python Versions](https://img.shields.io/badge/python-3.10-blue)](https://github.com/nuztalgia/bot-ui-kitty/blob/main/pyproject.toml)
[![Build Status](https://img.shields.io/github/workflow/status/nuztalgia/bot-ui-kitty/Build)](https://github.com/nuztalgia/bot-ui-kitty/actions/workflows/build.yml)
[![CodeQL Status](https://img.shields.io/github/workflow/status/nuztalgia/bot-ui-kitty/CodeQL?label=codeQL)](https://github.com/nuztalgia/bot-ui-kitty/actions/workflows/codeql.yml)
[![CodeFactor Grade](https://img.shields.io/codefactor/grade/github/nuztalgia/bot-ui-kitty/main?label=codefactor)](https://www.codefactor.io/repository/github/nuztalgia/bot-ui-kitty)

A collection of reusable and dynamic Discord UI views, built on top of Pycord's
[**Bot UI Kit**](https://docs.pycord.dev/en/master/api/ui_kit.html).

This library was originally created for personal use across my (many) Discord
bot projects, but I decided to make it more easily accessible just in case it's
useful to other bot developers too. 💜

## Installation

Python **3.10** is required (because Pycord doesn't officially support 3.11...
[yet](https://github.com/Pycord-Development/pycord/blob/master/CHANGELOG.md).)

```
pip install -U bot-ui-kitty
```

## Components

- [Dynamic Selector](https://github.com/nuztalgia/bot-ui-kitty/blob/aa9d33d7dc2e6658a93c45a8a48a85aaf74d5b96/uikitty/functions.py#L9-L36)

_Screenshots and usage info coming soon!_

## License

Copyright © 2022 [Nuztalgia](https://github.com/nuztalgia). Released under the
[Apache License, Version 2.0][license].

[license]: https://github.com/nuztalgia/bot-ui-kitty/blob/main/LICENSE
